@@ -25,6 +25,10 @@ in this Software without prior written authorization from The Open Group.
  * Author:  Chris D. Peterson, MIT X Consortium
  */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
